pychemstation.utils.constants API documentation

# pychemstation.utils.constants

View Source

     1from pychemstation.utils.hplc_param_types import Table
     2
     3# maximum command number
     4MAX_CMD_NO = 255
     5
     6# tables
     7METHOD_TIMETABLE = Table(
     8    register="RCPMP1Method[1]",
     9    name="Timetable"
    10)
    11
    12SEQUENCE_TABLE = Table(
    13    register="_sequence[1]",
    14    name="SeqTable1"
    15)

MAX_CMD_NO = 255
METHOD_TIMETABLE = Table(register='RCPMP1Method[1]', name='Timetable')
SEQUENCE_TABLE = Table(register='_sequence[1]', name='SeqTable1')